@@ -1,20 +1,20 @@
 /* *********************************************************** getargs.h *** *
- * TeoEyes - Teo Image Viewer
+ * ϴؿ إåե
  *
- * Copyright (C) 1998-2001 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 1998-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <2001-11-09 11:46:31 sugaya>
+ *                                    Time-stamp: <03/03/04 21:32:47 sugaya>
  * ************************************************************************* */
-#ifndef	_TE_GETARGS_H_
-#define	_TE_GETARGS_H_
+#ifndef	__GETARGS_H__
+#define	__GETARGS_H__
 
-void	usage 		(char		*s);
+void	usage 		(void);
 void	version 	(void);
 int	getargs 	(int		argc,
 			 char		**argv,
-			 Option		**opt,
-			 TeoeyesConfig	**tc);
+			 TEOption	**opt,
+			 TEConfig	**tc);
 
-#endif	/* _TE_GETARGS_H_ */
+#endif	/* __GETARGS_H__ */
 
 /* **************************************************** End of getargs.h *** */
