@@ -1,15 +1,16 @@
 /* ************************************************************ plugin.h *** *
- * TeoEyes - Teo Image Viewer
+ * $B%W%i%0%$%s$K4X$9$k4X?t(B $B%X%C%@%U%!%$%k(B
  *
- * Copyright (C) 2001 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
  *                                  Time-stamp: <2001-11-18 22:24:19 sugaya>
  * ************************************************************************* */
-#ifndef	_TE_PLUGIN_H_
-#define	_TE_PLUGIN_H_
+#ifndef	__PLUGIN_H__
+#define	__PLUGIN_H__
 
-void	te_plugin_menu_new 		(GtkWidget	*menu);
+void		plugin_menu_new 	(GtkMenuItem	*menu1,
+					 GtkMenuItem	*menu2);
 
-#endif	/* _TE_PLUGIN_H_ */
+#endif	/* __PLUGIN_H__ */
 
 /* ***************************************************** End of plugin.h *** */
