@@ -1,26 +1,26 @@
 /* ******************************************************* plugin_info.h *** *
- * TeoEyes - Teo Image Viewer
+ * ץ饰 إåե
  *
- * Copyright (C) 2001 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
  *                                  Time-stamp: <2001-11-20 23:20:25 sugaya>
  * ************************************************************************* */
-#ifndef	_PLUGIN_INFO_H_
-#define	_PLUGIN_INFO_H_
+#ifndef	__PLUGIN_INFO_H__
+#define	__PLUGIN_INFO_H__
 
 #include "gtkiconitemfactory.h"
 
 typedef struct _PluginInfo {
   GtkIconItemFactoryEntry	menu_item;             /* ˥塼Ѥι¤ */
-  char				*name;                               /* ̾ */
-  char				*author;                           /*  */
-  char				*version;                      /* С */
-  char				*help;                               /*  */
-  int				active;
-  void				(*plugin_func) (TEOIMAGE *,          /* ؿ */
-						TEOIMAGE *);
+  gchar				*name;                               /* ̾ */
+  gchar				*author;                           /*  */
+  gchar				*version;                      /* С */
+  gchar				*help;                               /*  */
+  gint				active;
+  void				(*plugin_func) (GdkPixbuf *,         /* ؿ */
+						GdkPixbuf *);
 } PluginInfo;   
 
-#endif	/* _PLUGIN_INFO_H_ */
+#endif	/* __PLUGIN_INFO_H__ */
 
 /* ************************************************ End of plugin_info.h *** */
